@@ -6,3 +6,6 @@ from .abstract_advanced_form_mixin import AbstractAdvancedFormMixin
 class AbstractAdvancedForm(AbstractAdvancedFormMixin, AbstractForm):
 
     settings_panels = AbstractAdvancedFormMixin.settings_panels
+
+    class Meta:
+        abstract = True
